python-oceans
=============

.. image:: https://badge.fury.io/py/oceans.png
   :target: http://badge.fury.io/py/oceans
.. image:: https://api.travis-ci.org/pyoceans/python-oceans.png?branch=master
   :target: https://travis-ci.org/pyoceans/python-oceans
.. image:: https://zenodo.org/badge/11956337.svg
   :target: https://zenodo.org/badge/latestdoi/11956337


Misc helper functions for ocean sciences.

Most of the functions here are Python versions of some common MatlabTM functions.
They are untested and probably buggy. Use with caution!
